@@ -16,6 +16,9 @@
 /* Define if LibGTop has support for multiple processors. */
 #undef HAVE_LIBGTOP_SMP
 
+/* Define if you have the LibGTop Documentation. */
+#undef HAVE_LIBGTOP_DOCU
+
 /* Define if there is no `u_int64_t' and `int64_t'. */
 #undef u_int64_t
 #undef int64_t
