@@ -265,7 +265,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_box_pack_start (GTK_BOX (vb), hb, FALSE, TRUE, 0);
 
 	frame = gtk_frame_new (_("Update times (textual summary)"));
-	table = gtk_table_new (4, 5, FALSE);
+	table = gtk_table_new (5, 5, FALSE);
 	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD);
 	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
 	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
@@ -362,6 +362,29 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 3, 4);
 
+	label = gtk_label_new (_("Details dialog"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 4, 5);
+
+	spin = gtk_spin_button_new (NULL, 1, 0);
+	adjustment = gtk_adjustment_new (1, 1, INT_MAX, 1, 100, 100);
+	gtk_spin_button_set_adjustment
+		(GTK_SPIN_BUTTON (spin), GTK_ADJUSTMENT (adjustment));
+	gtk_spin_button_set_value
+		(GTK_SPIN_BUTTON (spin),
+		 prop_ptr->update_times [GTOP_UPDATE_DETAILS]);
+	gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 4, 5);
+
+	gtk_signal_connect
+		(GTK_OBJECT (adjustment), "value_changed",
+		 adjustment_changed_cb, adjustment);
+
+	adjustments [GTOP_UPDATE_DETAILS] = GTK_ADJUSTMENT (adjustment);
+
+	label = gtk_label_new (_("ms"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 2, 3, 4, 5);
+
 	gtk_container_add (GTK_CONTAINER (frame), table);
 	hb = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start (GTK_BOX (hb), frame, TRUE, TRUE, 0);
@@ -461,6 +484,9 @@ global_properties_load (GnomePropertyObject *object)
 
 	gtop_properties.global.update_times [GTOP_UPDATE_STATUS_LOADAVG] =
 		gnome_config_get_int ("gtop/global/update_status_loadavg=1000");
+
+	gtop_properties.global.update_times [GTOP_UPDATE_DETAILS] =
+		gnome_config_get_int ("gtop/global/update_details=3000");
 }
 
 static void
@@ -513,4 +539,8 @@ global_properties_save (GnomePropertyObject *object)
 	gnome_config_set_int
 		("gtop/global/update_status_loadavg",
 		 gtop_properties.global.update_times [GTOP_UPDATE_STATUS_LOADAVG]);
+
+	gnome_config_set_int
+		("gtop/global/update_details",
+		 gtop_properties.global.update_times [GTOP_UPDATE_DETAILS]);
 }
