@@ -5,6 +5,10 @@
 #include <config.h>
 #include <gnome.h>
 
+#ifdef HAVE_LIMITS_H
+#include <limits.h>
+#endif
+
 #include "dummy.h"
 
 extern GnomeMDI *mdi;
@@ -16,4 +20,7 @@ extern void gtop_mdi_init (void);
 extern void gtop_mdi_start (gboolean);
 extern void gtop_quit (void);
 
+extern void gtop_init_libgtop (void);
+extern gint gtop_libgtop_is_summary_supported (gint);
+
 #endif
