@@ -164,9 +164,9 @@ graph_new (GtkWidget *da, GraphDataFunc d_fn, gpointer user_data)
 }
 
 void
-graph_destroy (GtkWidget *widget)
+graph_destroy (Graph *g)
 {
-	widget_list = g_list_remove (widget_list, widget);
+	widget_list = g_list_remove (widget_list, g);
 }
 
 #define GRAPH_WIDTH        (gtop_properties.graph.graph_width)
@@ -195,7 +195,7 @@ graph_process_data (Graph *g)
 	lines = total = 0;
 	w = h = 10;
 
-	if (!GTK_WIDGET_REALIZED (g->da))
+	if (!g->da || !GTK_WIDGET_REALIZED (g->da))
 		return;
 
 	gtk_widget_ensure_style (g->da);
@@ -462,7 +462,8 @@ graph_properties_update (GnomePropertyObject *object)
 {
 	GList *c;
 
-	gtk_widget_queue_resize (GTK_WIDGET (mdi->active_view));
+	if (mdi->active_view)
+		gtk_widget_queue_resize (GTK_WIDGET (mdi->active_view));
 
 	for (c = widget_list; c; c = c->next) {
 		Graph *graph = c->data;
@@ -513,6 +514,18 @@ graph_properties_apply (GnomePropertyObject *object)
 static void
 graph_properties_changed (GnomePropertyObject *object)
 {
+	GTopGraphProperties *temp_ptr = object->temp_data;
+	GTopGraphProperties *prop_ptr = object->prop_data;
+	gint i;
+
+	/* [FIXME]: Yes, this is an ugly hack, but we cannot fix it in
+	 *          libgnomeui right now. Sep 29, 1999 Martin Baulig */
+
+	for (i = 0; i < GRAPH_DEFAULT_COLORS+2; i++)
+		temp_ptr->colors [i] = prop_ptr->colors [i];
+
+	graph_properties_update (object);
+
 	gtop_properties_changed ();
 }
 
