@@ -383,9 +383,12 @@ static void
 procview_clist_button_press (GtkCList *cl, GdkEventButton *e,
 			     GTopProcViewData *d)
 {
+	gint row, col;
+
+	gtk_clist_get_selection_info (cl, e->x, e->y, &row, &col);
+
 	if (e->button != 1)
-		gtk_signal_emit_stop_by_name
-			(GTK_OBJECT (cl), "button_press_event");
+		gtk_clist_select_row (GTK_CLIST (cl), row, 0);
 
 	if ((d->select_pid != -1) && (e->button == 3))
 		gtk_menu_popup (GTK_MENU (d->clist_menu), NULL, NULL, NULL,
@@ -1497,7 +1500,7 @@ procfields_properties_load (GnomePropertyObject *object)
 		gint value;
 		gchar *tmp;
 
-		tmp = strchr (pos, ':');
+		tmp = strchr (pos, ',');
 		if (tmp) *tmp = '\0';
 
 		if (sscanf (pos, "%d", &value) == 1)
