@@ -98,6 +98,7 @@ static GtkWidget *summary_colors_properties_init (GnomePropertyObject *object);
 static void summary_colors_properties_update (GnomePropertyObject *object);
 static void summary_colors_properties_load (GnomePropertyObject *object);
 static void summary_colors_properties_save (GnomePropertyObject *object);
+static void summary_colors_properties_changed (GnomePropertyObject *object);
 
 GnomePropertyDescriptor SummaryColorsProperty_Descriptor = {
 	sizeof (GTopSummaryColorsProperties),
@@ -107,7 +108,9 @@ GnomePropertyDescriptor SummaryColorsProperty_Descriptor = {
 	summary_colors_properties_update,
 	summary_colors_properties_load,
 	summary_colors_properties_save,
-	NULL, NULL, NULL, NULL, NULL
+	NULL, NULL, NULL,
+	summary_colors_properties_changed,
+	NULL
 };
 
 GnomePropertyDescriptor SummaryProperty_Descriptor = {
@@ -1264,9 +1267,9 @@ summary_properties_save (GnomePropertyObject *object)
 static void
 summary_properties_apply (GnomePropertyObject *object)
 {
-    GTopSummaryProperties *prop_ptr = object->temp_data;
+	GTopSummaryProperties *prop_ptr = object->temp_data;
 
-    prop_ptr->maximum_loadavg = max_loadavg_adjustment->value;
+	prop_ptr->maximum_loadavg = max_loadavg_adjustment->value;
 }
 
 /* =======================================================================
@@ -1359,6 +1362,33 @@ summary_colors_properties_init (GnomePropertyObject *object)
 	return vb;
 }
 
+static void
+summary_colors_properties_changed (GnomePropertyObject *object)
+{
+	GTopSummaryColorsProperties *temp_ptr = object->temp_data;
+	GTopSummaryColorsProperties *prop_ptr = object->prop_data;
+	gint i;
+
+	/* [FIXME]: Yes, this is an ugly hack, but we cannot fix it in
+	 *          libgnomeui right now. Sep 29, 1999 Martin Baulig */
+
+	for (i = 0; i < 4; i++)
+		temp_ptr->cpu [i] = prop_ptr->cpu [i];
+
+	for (i = 0; i < 4; i++)
+		temp_ptr->mem [i] = prop_ptr->mem [i];
+
+	for (i = 0; i < 2; i++)
+		temp_ptr->swap [i] = prop_ptr->swap [i];
+
+	for (i = 0; i < 2; i++)
+		temp_ptr->load [i] = prop_ptr->load [i];
+
+	summary_colors_properties_update (object);
+
+	gtop_properties_changed ();
+}
+
 static void
 summary_colors_properties_load (GnomePropertyObject *object)
 {
